/*
 * JPLOT  -- Java Plotting Interface for any programme or
 *           as an independent GUI
 * 
 * Copyright (C) 1999 Jan van der Lee
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 *
 * Send bugs, suggestions or queries to <jplot@cig.ensmp.fr>
 * The latest releases are found at 
 * http://www.cig.ensmp.fr/~vanderlee/jplot.html
 *
 * Initally developed for use by the Centre d'Informatique Geologique 
 * Ecole des Mines de Paris, Fontainebleau, France.
 */

package jplot;

import java.awt.*;
import java.util.*;
import javax.swing.*;
import java.awt.event.*;
import javax.swing.border.*;

/**
 * Creates a panel with options to set or use grid lines in the graph.
 * Calling the <code>show</code> method pops up a frame (dialog) which
 * includes the panel.
 */
public class GridPanel extends GriddedPanel {

  private JDialog dialog;
  private JCheckBox cb_hg;
  private JCheckBox cb_vg;
  private JButton b_color;
  private Color actualColor;
  private ColorPanel colorPanel;
  private LineStyle lineStyle;
  private JPanel stylePanel;
  private GraphPars gp;
  private JPlot jplot;
  
  /**
   * Principal constructor. Builds a panel with grid options.
   * @param jp jplot instance
   * @param gp class with the global graphical parameters
   */
  public GridPanel (JPlot jp, GraphPars _gp) {
    gp = _gp;
    dialog = null;
    colorPanel = new ColorPanel(jplot.frame);
    actualColor = gp.getGridColor();
    jplot = jp;

    EmptyBorder border = new EmptyBorder(new Insets(0,0,0,10));
    Dimension cbField = new Dimension(110,24);

    // build the widgets:
    cb_hg = new JCheckBox("Horizontal",gp.drawGrid(gp.Y_AXIS));
    cb_vg = new JCheckBox("Vertical",gp.drawGrid(gp.X_AXIS));
    lineStyle = new LineStyle(new LinePars());
    lineStyle.setColor(actualColor);
    b_color = new JButton(new ImageIcon("color.jpg"));
    b_color.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
	Color color = colorPanel.show(jplot.frame,actualColor,100,100);
	if (color != null) {
	  actualColor = color;
	  lineStyle.setColor(actualColor);
	  lineStyle.repaint();
	}
      }
    });
    b_color.setMargin(new Insets(0,0,0,0));
    b_color.setToolTipText("Gridline color");
    stylePanel = new JPanel(new FlowLayout());
    stylePanel.add(lineStyle);
    stylePanel.add(b_color);

    // grid layout:
    JLabel label = new JLabel("Gridlines:");
    label.setBorder(border);
    addComponent(label,1,1);
    addComponent(cb_hg,1,2);
    addComponent(cb_vg,1,3);

    label = new JLabel("Gridcolor:");
    label.setBorder(border);
    addComponent(label,2,1);
    addComponent(stylePanel,2,2);
  }

  /**
   * Updates the panel with graph parameters.
   */
  public void refresh(GraphPars gp) {
    cb_hg.setSelected(gp.drawGrid(gp.Y_AXIS));
    cb_vg.setSelected(gp.drawGrid(gp.X_AXIS));
  }

  /**
   * Return the current values
   */
  public void setValues(GraphPars gp) {
    gp.setGridColor(actualColor);
    gp.setDrawGrid(gp.X_AXIS,cb_vg.isSelected());
    gp.setDrawGrid(gp.Y_AXIS,cb_hg.isSelected());
  }
  
  /**
   * Return a modal JDialog.
   */
  public void show(Frame parent, int x, int y) {
    if (dialog == null) {
      dialog = new JDialog(parent,"Labels",true);
      dialog.addWindowListener(new WindowAdapter() {
	public void windowClosing(WindowEvent e) {
	  dialog.dispose();
	}
      });
      dialog.getContentPane().add(this);
      dialog.setLocation(x,y);
      dialog.pack();
    }
    dialog.show();  // blocks until user brings dialog down.
  }
}

