/*
 * JPLOT  -- Java Plotting Interface for any programme or
 *           as an independent GUI
 * 
 * Copyright (C) 1999 Jan van der Lee
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 *
 * Send bugs, suggestions or queries to <jplot@cig.ensmp.fr>
 * The latest releases are found at 
 * http://www.cig.ensmp.fr/~vanderlee/jplot.html
 *
 * Initally developed for use by the Centre d'Informatique Geologique 
 * Ecole des Mines de Paris, Fontainebleau, France.
 */

package jplot;

import javax.swing.*;
import java.awt.geom.*;
import java.awt.*;

/**
 * Linestyle is a class which shows the current drawing style.
 * Returns a panel or canvas on which is paint the drawing
 * style according to the parameters past to the class.
 */
public class LineStyle extends JPanel {
  private Color backgroundColor;
  private Stroke stroke;
  private Stroke pointStroke;
  private Dimension panelSize;
  private double x_inset;
  private double y_inset;
  private double lineLength;
  private LinePars lp;
  private Rectangle rectangle;

  public LineStyle(LinePars l) {
    lp = l;
    backgroundColor = Color.white;
    panelSize = new Dimension(45,16);
    lineLength = 35.0;
    x_inset = ((double)panelSize.width - lineLength)/2.0;
    y_inset = (double)panelSize.height/2.0;
    rectangle = new Rectangle(0,0,panelSize.width,panelSize.height);
  }

  private void initialize() {
    float[] dash = {lp.getDashLength()};
    pointStroke = new BasicStroke(lp.getPenWidth());
    if (dash[0] < 0.0f) stroke = new BasicStroke(0.0f);
    else if (dash[0] == 0.0f) stroke = pointStroke;
    else stroke = new BasicStroke(lp.getPenWidth(),BasicStroke.CAP_SQUARE,
				  BasicStroke.JOIN_MITER,10.0f,dash,0.0f);
  }

  public void paintComponent(Graphics g) {
    Graphics2D g2 = (Graphics2D) g;
    g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, 
			RenderingHints.VALUE_ANTIALIAS_ON); 

    // clear the canvas:
    g2.setColor(backgroundColor);
    g2.fill(rectangle);
    
    // plot the linestyle:
    initialize();
    g2.setColor(lp.getColor());
    if (lp.drawLine()) {
      g2.setStroke(stroke);
      g2.draw(new Line2D.Double(x_inset,y_inset,lineLength+x_inset,y_inset));
    }
    if (lp.getSymbol() < 13 && lp.getSymbolSize() > 0.0f) {
      g2.setStroke(pointStroke);
      if (lp.drawSymbol()) {
	Graph.drawPointType(lp.getSymbol(),g2,x_inset+lineLength/2.0,
			    y_inset,lp.getSymbolSize());
      }
    }
  }

  public Dimension getPreferredSize() {
    return panelSize;
  }
  
  public LinePars getLinePars() {
    return lp;
  }

  public void setLinePars(LinePars lp) {
    this.lp = lp;
  }

  public void setColor(Color c) {
    lp.setColor(c);
  }

  public void setPenWidth(float f) {
    lp.setPenWidth(f);
  }

  public void setBackground(Color c) {
    backgroundColor = c;
  }
}
