/*
 * JPLOT  -- Java Plotting Interface for any programme or
 *           as an independent GUI
 * 
 * Copyright (C) 1999 Jan van der Lee
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 *
 * Send bugs, suggestions or queries to <jplot@cig.ensmp.fr>
 * The latest releases are found at 
 * http://www.cig.ensmp.fr/~vanderlee/jplot.html
 *
 * Initally developed for use by the Centre d'Informatique Geologique 
 * Ecole des Mines de Paris, Fontainebleau, France.
 */

package jplot;

import java.awt.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.event.*;

/**
 * Provides a number of handy functions which I use all the time,
 * but which are too short to bring into a package or class.
 */
class MyUtils {

  static final Font labelFont = new Font("SansSerif",Font.PLAIN,11);

  /**
   * Make a label specifically used by the tic-panel.
   * @param txt text of the label
   * @return a label with specific font and alignments.
   */
  static JLabel getLabel(String txt)
  {
    JLabel label = new JLabel(txt);
    label.setVerticalAlignment(SwingConstants.BOTTOM);
    label.setHorizontalAlignment(SwingConstants.CENTER);
    label.setFont(labelFont);
    label.setForeground(Color.black);
    return label;
  }

  /**
   * Builds a personalized checkbox using a smaller than usual font.
   */
  static JCheckBox createCheckBox(String s, boolean b) {
    JCheckBox cb = new JCheckBox(" " + s + " ",b);
    cb.setFont(new Font("serif", Font.PLAIN, 12));
    cb.setHorizontalAlignment(JCheckBox.LEFT);
    return cb;
  }

  /**
   * Very MS-Windoze-like. This panel builds a list and returns it
   * wrapped in a minimized scrollpane panel.
   * @param a array of objects which fill the list
   * @param index initially selected index
   * @return scrollpane panel 
   */
  static JScrollPane getCounter(Object[] a, int index) {
    JList list = new JList(a);
    list.setSelectedIndex(index);
    list.ensureIndexIsVisible(index);
    list.setVisibleRowCount(1);
    list.setSelectionBackground(list.getBackground());
    return new JScrollPane(list);
  }
}

