/*
 * JPLOT  -- Java Plotting Interface for any programme or
 *           as an independent GUI
 * 
 * Copyright (C) 1999 Jan van der Lee
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 *
 * Send bugs, suggestions or queries to <jplot@cig.ensmp.fr>
 * The latest releases are found at 
 * http://www.cig.ensmp.fr/~vanderlee/jplot.html
 *
 * Initally developed for use by the Centre d'Informatique Geologique 
 * Ecole des Mines de Paris, Fontainebleau, France.
 */

package jplot;

import java.util.*;
import java.awt.*;

/**
 * The <code>PlotPoint</code> defines a plot point in terms
 * of it's X- and Y value.
 */
public class PlotPoint {

  protected double x;
  protected double y;
  protected boolean lift;

  /**
   * Default constructor, initializes the class x- and y values.
   * @param x x-value;
   * @param y y-value;
   */
  public PlotPoint(double x, double y) {
    setPoint(x,y);
  }

  /**
   * Initializes the class x- and y values and sets the lift attribute.
   * @param x x-value;
   * @param y y-value;
   * @param liftNow true if the pen should lift at this point
   */
  public PlotPoint(double x, double y, boolean liftNow) {
    setPoint(x,y);
    lift = liftNow;
  }

  /**
   * Another constructor, initializes the class x- and y values.
   * @param pp PlotPoint instance
   */
  public PlotPoint(PlotPoint pp) {
    setPoint(pp);
  }

  /**
   * Sets x- and y values.
   * @param x x-value;
   * @param y y-value;
   */
  public void setPoint(double x, double y) {
    this.x = x;
    this.y = y;
  }

  /**
   * Sets x- and y values.
   * @param pp PlotPoint instance
   */
  public void setPoint(PlotPoint pp) {    
    this.x = pp.getX();
    this.y = pp.getY();
  }

  /**
   * returns x- and y values.
   * @return a PlotPoint instance with the current X- and Y values
   */
  public PlotPoint getPoint() {
    return new PlotPoint(x,y);
  }

  /**
   * Return the current X-value.
   * @return the current value of x
   */
  public double getX() {
    return x;
  }

  /**
   * Return the current Y-value.
   * @return the current value of y
   */
  public double getY() {
    return y;
  }

  /** 
   * Sets whether or not the drawing pen should be lifted after this point.
   * @param b true if the pen should lift
   */
  public void setLiftPen(boolean b) {
    lift = b;
  }

  /**
   * @return true if the pen should be lift after this point.
   */
  public boolean liftPen() {
    return lift;
  }
}

