/*
 * JPLOT  -- Java Plotting Interface for any programme or
 *           as an independent GUI
 * 
 * Copyright (C) 1999 Jan van der Lee
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 *
 * Send bugs, suggestions or queries to <jplot@cig.ensmp.fr>
 * The latest releases are found at 
 * http://www.cig.ensmp.fr/~vanderlee/jplot.html
 *
 * Initally developed for use by the Centre d'Informatique Geologique 
 * Ecole des Mines de Paris, Fontainebleau, France.
 */

package jplot;

import java.awt.*;
import java.util.*;
import javax.swing.*;
import java.awt.event.*;
import javax.swing.border.*;
import javax.swing.event.*;

/**
 * Builds a point-types panel from a number of predefined points,
 * all drawn by the Graph class.
 */
class PointPanel extends JPanel {
  float actualSize;
  SmallScrollPane ssp;
  JTextField tf_freq;
  String[] ten = {"30","24","20","18","!6","14","13","12","11","10","9","8","7","6","5","4","3","2","1"};
  LinePars lp;
  PointSwatches swatches;
  boolean actionNeeded;

  /**
   * Constructor.
   */
  public PointPanel(LinePars l) {
    lp = l;
    actionNeeded = false;
    setLayout(new BorderLayout());
    setBorder(new TitledBorder(new EtchedBorder(),"Points"));
    JPanel p = new JPanel();
    swatches = new PointSwatches();
    p.add(swatches);
    add(p,BorderLayout.CENTER);

    // add a widget to choose the symbol size:
    GriddedPanel south = new GriddedPanel();
    actualSize = lp.getSymbolSize();
    if (actualSize == 0.0f) actualSize = 5.0f;
    ssp = new SmallScrollPane(ten,true);
    ssp.getViewport().addChangeListener(new ChangeListener() {
      public void stateChanged(ChangeEvent e) {
	if (actionNeeded) {
	  actualSize = Float.parseFloat(ten[ssp.getSelectedIndex()]);
	  if (lp.getSymbol() <= GraphPars.NO_SYMBOL) {
	    lp.setSymbolSize(actualSize);
	  }
	}
      }
    });

    // add a widget to choose the 'every' option:
    tf_freq = new JTextField(Integer.toString(lp.getPointFrequency()));
    tf_freq.addCaretListener(new CaretListener() {
      public void caretUpdate(CaretEvent e) {
	if (!tf_freq.getText().equals("")) {
	  int k = Integer.parseInt(tf_freq.getText());
	  if (k > 0) lp.setPointFrequency(k);
	  //System.out.println("every set to " + k);
	}
      }
    });
    tf_freq.setColumns(3);

    // place the widgets
    south.addComponent(MyUtils.getLabel("frequency"),1,1);
    south.addComponent(tf_freq,1,2);
    south.addComponent(MyUtils.getLabel("point size"),2,1);
    south.addComponent(ssp,2,2);
    add(south,BorderLayout.SOUTH);
  }

  /**
   * Refreshes the panel with the current data.
   * @param l line parameter class
   */
  public void refresh(LinePars l) {
    lp = l;
    actionNeeded = true;
    actualSize = lp.getSymbolSize();
    tf_freq.setText(Integer.toString(lp.getPointFrequency()));
    //ssp.setSelectedIndex(ten.length-(int)actualSize+3);
    ssp.setSelected(Integer.toString((int)actualSize));
    swatches.setSelectedSwatch(lp.getSymbol());
  }

  class PointSwatches extends SwatchPanel {
    public PointSwatches() {
      //super();
      setSelectedSwatch(lp.getSymbol());
      addMouseListener(new MouseAdapter() {
	public void mouseClicked(MouseEvent e) {
	  if (e.getClickCount() == 1) {
	    int index = getIndex(e.getX(),e.getY());
	    setSelectedSwatch(index);
	    lp.setSymbol(index);
	    lp.setSymbolSize(actualSize);
	  }
	}
      });
    }
    
    protected void initValues() {
      swatchSize = new Dimension(30,12);
      numSwatches = new Dimension(2,7);
    }
    
    protected void paintIt(Graphics2D g2, int column, int row, int x, int y) {
      g2.setColor(Color.black);
      int type = (row*numSwatches.width)+column;
      Graph.drawPointType(type,g2,(double)(x+swatchSize.width/2),
			  (float)(y+swatchSize.height/2),5);
    }
    
    public String getToolTipText(MouseEvent e) {
      int i = getIndex(e.getX(),e.getY());
      if (i >= 0 && i < Ns) {
	return "point type " + new Integer(i).toString();
      }
      return "";
    }  
  }
}
