/*
 * JPLOT  -- Java Plotting Interface for any programme or
 *           as an independent GUI
 * 
 * Copyright (C) 1999 Jan van der Lee
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 *
 * Send bugs, suggestions or queries to <jplot@cig.ensmp.fr>
 * The latest releases are found at 
 * http://www.cig.ensmp.fr/~vanderlee/jplot.html
 *
 * Initally developed for use by the Centre d'Informatique Geologique 
 * Ecole des Mines de Paris, Fontainebleau, France.
 */
package jplot;

import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;
import java.io.*;

import java.awt.event.*;
import java.awt.*;

/**
 * Class small button displays a button in the new 'window' style,
 * i.e., you only see the button in raised or lowered state if you
 * are on it with the mouse.
 */
public class SmallButton extends JButton implements MouseListener {

  protected Border raised;
  protected Border lowered;
  protected Border inactive;

  /**
   * Principal constructor, builds the button with a specific
   * action and a tool tip.
   * @param action action performed when pressing
   * @param tip tool tip
   */
  public SmallButton(Action action, String tip) {
    super((Icon)action.getValue(Action.SMALL_ICON));
    raised = new BevelBorder(BevelBorder.RAISED);
    lowered = new BevelBorder(BevelBorder.LOWERED);
    inactive = new EmptyBorder(2,2,2,2);
    setBorder(inactive);
    setMargin(new Insets(1,1,1,1));
    setToolTipText(tip);
    addActionListener(action);
    addMouseListener(this);
    setRequestFocusEnabled(false);
  }

  public float getAlignmentY() {
    return 0.5f;
  }
  
  public void mousePressed(MouseEvent e) {
    setBorder(lowered);
  }

  public void mouseReleased(MouseEvent e) {
    setBorder(inactive);
  }

  public void mouseEntered(MouseEvent e) {
    setBorder(raised);
  }

  public void mouseExited(MouseEvent e) {
    setBorder(inactive);
  }

  public void mouseClicked(MouseEvent e) {}

  
}
