/*
 * JPLOT  -- Java Plotting Interface for any programme or
 *           as an independent GUI
 * 
 * Copyright (C) 1999 Jan van der Lee
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 *
 * Send bugs, suggestions or queries to <jplot@cig.ensmp.fr>
 * The latest releases are found at 
 * http://www.cig.ensmp.fr/~vanderlee/jplot.html
 *
 * Initally developed for use by the Centre d'Informatique Geologique 
 * Ecole des Mines de Paris, Fontainebleau, France.
 */

package jplot;

import java.awt.*;
import javax.swing.*;

/**
 * Very MS-Windoze-like. This panel builds a list and returns it
 * wrapped in a minimized scrollpane panel.
 */
class SmallScrollPane extends JScrollPane {
  
  JViewport vp;
  JList list;

  /**
   * Constructor. We build a list and return it wrapped in a
   * minimized scrollpane panel.
   * @param a array of objects which fill the list
   * @param index initially selected index
   * @return scrollpane panel 
   */
  public SmallScrollPane(Object[] a, boolean editable) {
    list = new JList(a);
    //list.setSelectedIndex(index);
    list.setVisibleRowCount(1);
    vp = getViewport();
    vp.setView(list);
    //list.ensureIndexIsVisible(index);
    list.setSelectionBackground(list.getBackground());
  }

  /**
   * Constructor. We build a list and return it wrapped in a
   * minimized scrollpane panel.
   * @param a array of objects which fill the list
   * @param index initially selected index
   * @return scrollpane panel 
   */
  public SmallScrollPane(Object[] a) {
    this(a,false);
  }

  /**
   * Returns the selected index of the scrollpane.
   * @return the selected index of the scrollpane.
   */
  public int getSelectedIndex() {
    return list.locationToIndex(vp.getViewPosition());
  }

  /**
   * Sets the selected index and lets the viewport scroll
   * to the item corresponding to this index.
   * @param index selected index
   */
  public void setSelectedIndex(int index) {
    list.setSelectedIndex(index);
    list.ensureIndexIsVisible(index);
    //vp.setViewPosition(list.indexToLocation(selectedIndex));
  }

  /**
   * Sets the selected item and lets the viewport scroll
   * to the item corresponding to this index.
   * @param item item which should be visible and selected
   */
  public void setSelected(Object item) {
    list.setSelectedValue(item,true);
  }
}

